@@ -9,7 +9,7 @@ use Types::Standard -types;
 use Capture::Tiny qw/capture/;
 use failures qw/module::comparison/;
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 has perl_path => (is => 'ro', isa => Str, default => '');
 has modules => (is => 'ro', isa => ArrayRef);
@@ -227,7 +227,7 @@ sub human_readable_report
     }
     if(%{$report->{updated}})
     {
-        push @lines, 'Udated Modules', '';
+        push @lines, 'Updated Modules', '';
         for my $key (sort keys %{$report->{updated}}) 
         {
             my ($v1, $v2) = @{$report->{updated}->{$key}};
@@ -256,7 +256,7 @@ Server::Module::Comparison - check perl module versions installed on servers.
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
